TextSearchResultDelegate class
- Inheritance
-
- Object
- SingleChildLayoutDelegate
- TextSearchResultDelegate
Constructors
-
TextSearchResultDelegate(ValueNotifier<
Size> _size, {required double minHeight, required double maxHeight})
Properties
Methods
-
getConstraintsForChild(
BoxConstraints constraints) → BoxConstraints -
The constraints for the child given the incoming constraints.
override
-
getPositionForChild(
Size size, Size childSize) → Offset -
The position where the child should be placed.
inherited
-
getSize(
BoxConstraints constraints) → Size -
The size of this object given the incoming constraints.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRelayout(
covariant TextSearchResultDelegate oldDelegate) → bool -
Called whenever a new instance of the custom layout delegate class is
provided to the RenderCustomSingleChildLayoutBox object, or any time
that a new CustomSingleChildLayout object is created with a new instance
of the custom layout delegate class (which amounts to the same thing,
because the latter is implemented in terms of the former).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited