SearchableTextFormField<T extends Searchable> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SearchableTextFormField
Constructors
-
SearchableTextFormField({Key? key, required TextEditingController controller, required Widget? itemBuilder(T), dynamic onSelect(T)?, void onChanged(String)?, List<
T> searchFilter(String)?, Future<List< search(String)?, InputDecoration? decoration, SearchResultView resultView = SearchResultView.list, String? validator(String?)?, String? hintText, Color? backgroundColor, double? bottomPadding, double? endPadding, double? elevation, double? borderRadius, double? minHeight, double? maxHeight})T> ?> -
const
Properties
- backgroundColor → Color?
-
final
- borderRadius → double?
-
final
- bottomPadding → double?
-
final
- controller → TextEditingController
-
final
- decoration → InputDecoration?
-
final
- elevation → double?
-
final
- endPadding → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
final
- itemBuilder → Widget? Function(T)
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxHeight → double?
-
final
- minHeight → double?
-
final
- onChanged → void Function(String)?
-
final
- onSelect → dynamic Function(T)?
-
final
- resultView → SearchResultView
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
search
→ Future<
List< Function(String)?T> ?> -
final
-
searchFilter
→ List<
T> Function(String)? -
final
- validator → String? Function(String?)?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SearchableTextFormField< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited