getSize method
The size of this object given the incoming constraints.
Defaults to the biggest size that satisfies the given constraints.
Implementation
@override
Size getSize(BoxConstraints constraints) {
debugPrint('TextSearchResultDelegate: getSize(): ${_size.value} -------');
return _size.value;
}